@@ -67,6 +67,9 @@
 #' \code{\link{read_interpolator}()}, \code{\link{set_interpolation_params}()},
 #' \code{\link{with_meteo}()}, \code{\link{write_interpolator}()}
 #'
+#' @author 
+#' Victor Granda \enc{García}{Garcia}, EMF-CREAF
+#' 
 #' @examples
 #' # example interpolator
 #' data(meteoland_interpolator_example)
@@ -100,6 +103,9 @@ get_interpolation_params <- function(interpolator) {
 #' \code{\link{get_interpolation_params}()}, \code{\link{read_interpolator}()},
 #' \code{\link{with_meteo}()}, \code{\link{write_interpolator}()}
 #'
+#' @author 
+#' Victor Granda \enc{García}{Garcia}, EMF-CREAF
+#' 
 #' @examples
 #' # example interpolator
 #' data(meteoland_interpolator_example)
@@ -158,6 +164,11 @@ set_interpolation_params <- function(interpolator, params = NULL, verbose = getO
 #' \code{\link{set_interpolation_params}()}, \code{\link{with_meteo}()},
 #' \code{\link{write_interpolator}()}
 #'
+#' @author 
+#' Victor Granda \enc{García}{Garcia}, EMF-CREAF
+#' 
+#' Miquel De \enc{Cáceres}{Caceres} Ainsa, EMF-CREAF
+#' 
 #' @examples
 #'
 #' # example meteo data
@@ -368,7 +379,18 @@ create_meteo_interpolator <- function(meteo_with_topo, params = NULL, verbose =
     cli::cli_ul("Updating intial_Rp parameter with the actual stations mean distance..."),
     verbose
   )
+
   params$initial_Rp <-
+    meteo_arranged |>
+    # We need to pass the Rp in the same units the coordinates are,
+    # because the C++ methods calculate distances with the points as
+    # planar/cartesian distances. i.e. If Rp are in meters (which happens
+    # if we have a CRS setted), but coordinates are lat/long, C++ methods will
+    # calculate distance with points wrongly (as coordinates are in degrees)
+    # For this, we extract the coordinates and pass unique. This ensures the
+    # CRS is lost, so distances are calculated in the arbitrary units (the
+    # same as coordinates).
+    # dplyr::select(attr(meteo_arranged, "sf_column")) |>
     sf::st_geometry(meteo_arranged) |>
     unique() |>
     sf::st_as_sfc() |>
@@ -376,6 +398,19 @@ create_meteo_interpolator <- function(meteo_with_topo, params = NULL, verbose =
     as.numeric() |>
     mean(na.rm = TRUE)
 
+  ### We cannot give a warning now, because we don't know the units a priori
+  ### (Unless we recalculate the distance again, this time with units)
+  # give a warning if mean distance is bigger than 100 km
+  # if (params$initial_Rp > 100000) {
+  #   cli::cli_alert_danger(
+  #     "initial_Rp value (mean distance between meteorological stations) is {.strong {round(params$initial_Rp / 1000, 2)}km}"
+  #   )
+  #   cli::cli_alert_info(c(
+  #     "Please check the meteorological data. ",
+  #     "Interpolation results can be affected when stations are scattered and with great distances between them."
+  #   ))
+  # }
+
   # set the params as an attribute of stars_interpolator
   attr(stars_interpolator, "params") <- params
 
@@ -432,6 +467,9 @@ create_meteo_interpolator <- function(meteo_with_topo, params = NULL, verbose =
 #' # read it again
 #' read_interpolator(file.path(tmp_dir, "meteoland_interpolator_example.nc"))
 #' }
+#' 
+#' @author 
+#' Victor Granda \enc{García}{Garcia}, EMF-CREAF
 #'
 #' @export write_interpolator
 write_interpolator <- function(interpolator, filename, .overwrite = FALSE) {
@@ -570,6 +608,9 @@ write_interpolator <- function(interpolator, filename, .overwrite = FALSE) {
 #' read_interpolator(file.path(tmp_dir, "meteoland_interpolator_example.nc"))
 #' }
 #'
+#' @author 
+#' Victor Granda \enc{García}{Garcia}, EMF-CREAF
+#' 
 #' @export read_interpolator
 read_interpolator <- function(filename) {
   # debug
@@ -662,11 +703,17 @@ read_interpolator <- function(filename) {
 #' predictive \code{"MAE"} calculation.
 #' @param variable A string indicating the meteorological variable for which
 #' interpolation parameters \code{"N"} and \code{"alpha"} will be calibrated.
-#' Accepted values are \code{MinTemperature}, \code{MaxTemperature},
-#' \code{DewTemperature}, \code{Precipitation} (for precipitation with the same
-#' values for precipitation events an regression of precipitation amounts),
-#' \code{PrecipitationAmount} (for regression of precipitation amounts) and
-#' \code{PrecipitationEvent} (for precipitation events).
+#' Accepted values are:
+#'   \itemize{
+#'     \item{\code{MinTemperature} (kernel for minimum temperature)}
+#'     \item{\code{MaxTemperature} (kernel for maximum temperature)}
+#'     \item{\code{DewTemperature} (kernel for dew-temperature (i.e. relative humidity))}
+#'     \item{\code{Precipitation} (to calibrate the same
+#'           kernel for both precipitation events and regression of precipitation amounts;
+#'           not recommended)}
+#'     \item{\code{PrecipitationAmount} (kernel for regression of precipitation amounts)}
+#'     \item{\code{PrecipitationEvent} (kernel for precipitation events)}
+#'   }
 #' @param N_seq Numeric vector with \code{"N"} values to be tested
 #' @param alpha_seq Numeric vector with \code{"alpha"}
 #' @param update_interpolation_params Logical indicating if the interpolator
@@ -687,6 +734,20 @@ read_interpolator <- function(filename) {
 #' \code{update_interpolation_params} is FALSE, \code{interpolator_calibration}
 #' returns the interpolator provided with the parameters updated
 #'
+#' @references Thornton, P.E., Running, S.W., 1999. An improved algorithm for
+#' estimating incident daily solar radiation from measurements of temperature,
+#' humidity, and precipitation. Agric. For. Meteorol. 93, 211–228.
+#' doi:10.1016/S0168-1923(98)00126-9.
+#'
+#' De Caceres M, Martin-StPaul N, Turco M, Cabon A, Granda V (2018) Estimating
+#' daily meteorological data and downscaling climate models over landscapes.
+#' Environmental Modelling and Software 108: 186-196.
+#'
+#' @author 
+#' Miquel De \enc{Cáceres}{Caceres} Ainsa, EMF-CREAF
+#' 
+#' Victor Granda \enc{García}{Garcia}, EMF-CREAF
+#' 
 #' @examples
 #'
 #' \donttest{
@@ -714,6 +775,7 @@ read_interpolator <- function(filename) {
 #'   alpha_seq = seq(8, 9, by = 0.25)
 #' )
 #'
+#'
 #' # check the new interpolator have the parameters updated
 #' get_interpolation_params(updated_interpolator)$N_MaxTemperature
 #' get_interpolation_params(updated_interpolator)$alpha_MaxTemperature
@@ -724,10 +786,7 @@ interpolator_calibration <- function(
     interpolator,
     stations = NULL,
     update_interpolation_params = FALSE,
-    variable = c(
-      "MinTemperature", "MaxTemperature", "DewTemperature",
-      "Precipitation", "PrecipitationAmount", "PrecipitationEvent"
-    ),
+    variable = "MinTemperature",
     N_seq = seq(5, 30, by = 5),
     alpha_seq = seq(0.25, 10, by = 0.25),
     verbose = getOption("meteoland_verbosity", TRUE)
@@ -745,7 +804,10 @@ interpolator_calibration <- function(
   assertthat::assert_that(
     is.character(variable), msg = "variable argument must be a character"
   )
-  variable <- match.arg(variable)
+  variable <- match.arg(variable, choices = c(
+    "MinTemperature", "MaxTemperature", "DewTemperature",
+    "Precipitation", "PrecipitationAmount", "PrecipitationEvent"
+  ))
   # seqs
   assertthat::assert_that(
     is.numeric(N_seq),
